"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const index_1 = require("../index");
const test_1 = require("@schematics/angular/utility/test");
function addFireBug(options) {
    const source = schematics_1.apply(schematics_1.url('../utils/firebug/files'), [
        schematics_1.move(`${options.directory}/src/bootstrapScripts`)
    ]);
    return schematics_1.chain([
        schematics_1.mergeWith(source),
        index_1.addDependencyToPackageJson(options, 'node-wget', '^0.4.2', true),
        index_1.addDependencyToPackageJson(options, 'decompress', '^4.2.0', true),
        index_1.addDependencyToPackageJson(options, 'decompress-targz', '^4.1.1', true),
        tree => {
            let indexContent = '';
            if (tree.exists(`${options.directory}/src/bootstrapScripts/index.ts`)) {
                indexContent = test_1.getFileContent(tree, `${options.directory}/src/bootstrapScripts/index.ts`);
            }
            index_1.createOrOverwriteFile(tree, `${options.directory}/src/bootstrapScripts/index.ts`, indexContent + 'export * from \'./firebug\';\n');
            //find and overwrite environment files
            index_1.createOrOverwriteFile(tree, `${options.directory}/src/environments/environment.firebug.ts`, test_1.getFileContent(tree, `${options.directory}/src/environments/environment.ts`));
            tree.getDir(`${options.directory}/src/environments`).visit((path) => {
                if (path.endsWith('.ts')) {
                    index_1.addEntryToEnvironment(tree, path, 'firebug', path.indexOf('firebug') > -1);
                }
            });
            let mainFilePath;
            //add new configuration to serve
            if (tree.exists(`${options.directory}/angular.json`)) {
                const cliConfig = JSON.parse(test_1.getFileContent(tree, `${options.directory}/angular.json`));
                mainFilePath = `${options.directory}/` + cliConfig.projects[options.name].architect.build.options.main;
                cliConfig.projects[options.name].architect.serve.configurations.firebug = { browserTarget: `${options.name}:build:firebug` };
                index_1.createOrOverwriteFile(tree, `${options.directory}/angular.json`, JSON.stringify(cliConfig, null, '  '));
            }
            else {
                const configSource = JSON.parse(test_1.getFileContent(tree, `${options.directory}/.angular-cli.json`));
                mainFilePath = `${options.directory}/${configSource.apps[0].root}/main.browser.ts`;
            }
            //find and add code to the main browser file
            index_1.addImportStatement(tree, mainFilePath, 'import { fireBug } from \'./bootstrapScripts\';');
            const sourceText = test_1.getFileContent(tree, mainFilePath);
            index_1.createOrOverwriteFile(tree, mainFilePath, sourceText.replace('platformBrowserDynamic().bootstrapModule(AppBrowserModule);', 'fireBug().then(() => platformBrowserDynamic().bootstrapModule(AppBrowserModule));'));
            //adding postinstal script
            let postInstall = '';
            if (tree.exists(`${options.directory}/postinstall.js`)) {
                postInstall = test_1.getFileContent(tree, `${options.directory}/postinstall.js`);
            }
            postInstall = `
const fs = require('fs');
const wget = require('node-wget');
const decompress = require('decompress');
const decompressTargz = require('decompress-targz');

if (!fs.existsSync('./firebug-lite.tar.tgz')) {
  console.log('Downloading firebug.');
  wget({url: 'https://getfirebug.com/releases/lite/latest/firebug-lite.tar.tgz', dest: './'}, () => {
    console.log('Downloaded.');
    decompress('firebug-lite.tar.tgz', '.', {
      plugins: [
        decompressTargz()
      ]
    }).then(() => console.log('Decompressed.'));
  });
}` + postInstall;
            index_1.createOrOverwriteFile(tree, `${options.directory}/postinstall.js`, postInstall);
            return tree;
        }
    ]);
}
exports.addFireBug = addFireBug;
//# sourceMappingURL=index.js.map