"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const index_1 = require("../index");
const index_2 = require("../firebug/index");
const index_3 = require("../googleAnalytics/index");
const test_1 = require("@schematics/angular/utility/test");
function newApp(options) {
    const templateSource = schematics_1.apply(schematics_1.url('../utils/new-app/files'), [
        schematics_1.move(options.directory),
    ]);
    let rules = [];
    rules.push(schematics_1.mergeWith(templateSource, schematics_1.MergeStrategy.Overwrite));
    rules.push(overwriteMainFile(options));
    rules.push(index_1.createGitIgnore(options.directory));
    rules.push(index_1.addServerless(options));
    rules.push((tree => {
        const packageJsonSource = JSON.parse(test_1.getFileContent(tree, `${options.directory}/package.json`));
        packageJsonSource['collective'] = {
            type: "opencollective",
            url: "https://opencollective.com/angular-universal-pwa"
        };
        tree.overwrite(`${options.directory}/package.json`, JSON.stringify(packageJsonSource, null, "  "));
        return tree;
    }));
    rules.push(updatePackageJson(options));
    if (options.firebug) {
        rules.push(index_2.addFireBug(options));
        rules.push(index_1.addOrReplaceScriptInPackageJson(options, 'build:watch:firebug', 'ng serve -env=firebug'));
        rules.push(index_1.addOrReplaceScriptInPackageJson(options, 'build:firebug', 'run-p build:watch:firebug credentials'));
    }
    if (options.gaTrackingCode) {
        rules.push(index_3.addGoogleAnalytics(options));
    }
    return schematics_1.chain(rules);
}
exports.newApp = newApp;
function updatePackageJson(options) {
    return schematics_1.chain([
        index_1.addOrReplaceScriptInPackageJson(options, 'postinstall', 'node postinstall.js'),
        index_1.addOrReplaceScriptInPackageJson(options, 'ng', 'ng'),
        index_1.addOrReplaceScriptInPackageJson(options, 'start', 'run-p build:watch credentials'),
        index_1.addOrReplaceScriptInPackageJson(options, 'build:watch', 'ng serve'),
        index_1.addOrReplaceScriptInPackageJson(options, 'credentials', 'node credentials.js && opencollective postinstall'),
        index_1.addOrReplaceScriptInPackageJson(options, 'test', 'ng test --single-run --code-coverage'),
        index_1.addOrReplaceScriptInPackageJson(options, 'test:watch', 'ng test --code-coverage'),
        index_1.addOrReplaceScriptInPackageJson(options, 'build:dev', 'run-p test:watch start'),
        index_1.addOrReplaceScriptInPackageJson(options, 'build', 'ng build'),
        index_1.addOrReplaceScriptInPackageJson(options, 'lint', 'ng lint --fix'),
        index_1.addOrReplaceScriptInPackageJson(options, 'build:prod', 'npm run test && npm run build:client-and-server-bundles && npm run webpack:server'),
        index_1.addOrReplaceScriptInPackageJson(options, 'webpack:server', 'webpack --config webpack.server.config.js --progress --colors'),
        index_1.addOrReplaceScriptInPackageJson(options, 'server', 'node local.js'),
        index_1.addDependencyToPackageJson(options, 'cors', '~2.8.4'),
        index_1.addDependencyToPackageJson(options, '@nguniversal/common', '^5.0.0-beta.8'),
        index_1.addDependencyToPackageJson(options, '@nguniversal/express-engine', '^5.0.0-beta.8'),
        index_1.addDependencyToPackageJson(options, '@nguniversal/module-map-ngfactory-loader', '^5.0.0-beta.8'),
        index_1.addDependencyToPackageJson(options, 'typescript-collections', '^1.3.2'),
        index_1.addDependencyToPackageJson(options, 'cp-cli', '^1.1.0', true),
        index_1.addDependencyToPackageJson(options, 'cpy-cli', '^1.0.1', true),
        index_1.addDependencyToPackageJson(options, 'decompress', '^4.2.0', true),
        index_1.addDependencyToPackageJson(options, 'decompress-targz', '^4.1.1', true),
        index_1.addDependencyToPackageJson(options, 'express', '^4.15.2', true),
        index_1.addDependencyToPackageJson(options, 'http-server', '^0.10.0', true),
        index_1.addDependencyToPackageJson(options, 'karma-phantomjs-launcher', '^1.0.4', true),
        index_1.addDependencyToPackageJson(options, 'node-wget', '^0.4.2', true),
        index_1.addDependencyToPackageJson(options, 'npm-run-all', '^4.1.2', true),
        index_1.addDependencyToPackageJson(options, 'opencollective', '^1.0.3', true),
        index_1.addDependencyToPackageJson(options, 'pre-commit', '^1.2.2', true),
        index_1.addDependencyToPackageJson(options, 'reflect-metadata', '^0.1.10', true),
        index_1.addDependencyToPackageJson(options, 'serverless', '^1.26.1', true),
        index_1.addDependencyToPackageJson(options, 'sinon', '^4.5.0', true),
        index_1.addDependencyToPackageJson(options, 'tslint', '^5.7.0', true)
    ]);
}
function overwriteMainFile(options) {
    return (tree => {
        tree.rename(`${options.directory}/src/main.ts`, `${options.directory}/src/main.browser.ts`);
        index_1.createOrOverwriteFile(tree, `${options.directory}/src/main.browser.ts`, `import { enableProdMode } from '@angular/core';
    import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';

    import { environment } from './environments/environment';
    import { AppBrowserModule } from './app/app.browser.module';

    if (environment.production) {
        enableProdMode();
    }

    platformBrowserDynamic().bootstrapModule(AppBrowserModule);
    `);
        return tree;
    });
}
//# sourceMappingURL=index.js.map